@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- * $Id: pcsc_demo.c,v 1.7 2007-02-13 20:38:52 rousseau Exp $
+ * $Id: pcsc_demo.c 2563 2007-06-17 12:10:55Z rousseau $
  */
 
 #include <stdio.h>
@@ -66,7 +66,7 @@ int main(int argc, char *argv[])
     SCARD_IO_REQUEST *pioSendPci;
 	SCARD_IO_REQUEST pioRecvPci;
 	BYTE pbRecvBuffer[10];
-	BYTE pbSendBuffer[] = { 0xC0, 0xA4, 0x00, 0x00, 0x02, 0x3F, 0x00 };
+	BYTE pbSendBuffer[] = { 0x00, 0xA4, 0x00, 0x00, 0x02, 0x3F, 0x00 };
 	DWORD dwSendLength, dwRecvLength;
 
 	printf("PC/SC sample code\n");
@@ -79,7 +79,7 @@ int main(int argc, char *argv[])
 	if (rv != SCARD_S_SUCCESS)
 	{
 		printf("SCardEstablishContext: Cannot Connect to Resource Manager %lX\n", rv);
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/* Retrieve the available readers list.
@@ -190,8 +190,16 @@ int main(int argc, char *argv[])
 	/* exchange APDU */
 	dwSendLength = sizeof(pbSendBuffer);
 	dwRecvLength = sizeof(pbRecvBuffer);
+	printf("Sending: ");
+	for (i=0; i<dwSendLength; i++)
+		printf("%02X ", pbSendBuffer[i]);
+	printf("\n");
 	rv = SCardTransmit(hCard, pioSendPci, pbSendBuffer, dwSendLength,
 		&pioRecvPci, pbRecvBuffer, &dwRecvLength);
+	printf("Received: ");
+	for (i=0; i<dwRecvLength; i++)
+		printf("%02X ", pbRecvBuffer[i]);
+	printf("\n");
 	PCSC_ERROR(rv, "SCardTransmit")
 
 	/* card disconnect */
@@ -208,8 +216,16 @@ int main(int argc, char *argv[])
 	/* exchange APDU */
 	dwSendLength = sizeof(pbSendBuffer);
 	dwRecvLength = sizeof(pbRecvBuffer);
+	printf("Sending: ");
+	for (i=0; i<dwSendLength; i++)
+		printf("%02X ", pbSendBuffer[i]);
+	printf("\n");
 	rv = SCardTransmit(hCard, pioSendPci, pbSendBuffer, dwSendLength,
 		&pioRecvPci, pbRecvBuffer, &dwRecvLength);
+	printf("Received: ");
+	for (i=0; i<dwRecvLength; i++)
+		printf("%02X ", pbRecvBuffer[i]);
+	printf("\n");
 	PCSC_ERROR(rv, "SCardTransmit")
 
 	/* card reconnect */
@@ -252,8 +268,16 @@ int main(int argc, char *argv[])
 	/* exchange APDU */
 	dwSendLength = sizeof(pbSendBuffer);
 	dwRecvLength = sizeof(pbRecvBuffer);
+	printf("Sending: ");
+	for (i=0; i<dwSendLength; i++)
+		printf("%02X ", pbSendBuffer[i]);
+	printf("\n");
 	rv = SCardTransmit(hCard, pioSendPci, pbSendBuffer, dwSendLength,
 		&pioRecvPci, pbRecvBuffer, &dwRecvLength);
+	printf("Received: ");
+	for (i=0; i<dwRecvLength; i++)
+		printf("%02X ", pbRecvBuffer[i]);
+	printf("\n");
 	PCSC_ERROR(rv, "SCardTransmit")
 
 	/* end transaction */
