@@ -7,7 +7,7 @@
  *  Toni Andjelkovic <toni@soth.at>
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *
- * $Id: hotplug_libusb.c,v 1.9 2007-02-13 20:38:52 rousseau Exp $
+ * $Id: hotplug_libusb.c 2561 2007-06-13 12:48:12Z rousseau $
  */
 
 /**
@@ -89,7 +89,7 @@ static struct _readerTracker
 LONG HPReadBundleValues(void);
 LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
 	struct _driverTracker *driver);
-LONG HPRemoveHotPluggable(int index);
+LONG HPRemoveHotPluggable(int reader_index);
 static void HPRescanUsbBus(void);
 static void HPEstablishUSBNotifications(void);
 
@@ -97,7 +97,7 @@ LONG HPReadBundleValues(void)
 {
 	LONG rv;
 	DIR *hpDir;
-	struct dirent *currFP = 0;
+	struct dirent *currFP = NULL;
 	char fullPath[FILENAME_MAX];
 	char fullLibPath[FILENAME_MAX];
 	char keyValue[TOKEN_MAX_VALUE_SIZE];
@@ -142,50 +142,54 @@ LONG HPReadBundleValues(void)
 				driverTracker[listCount].bundleName = strdup(currFP->d_name);
 
 				/* Get ifdVendorID */
-				rv = LTPBundleFindValueWithKey(fullPath, PCSCLITE_HP_MANUKEY_NAME,
-					keyValue, alias);
+				rv = LTPBundleFindValueWithKey(fullPath,
+					PCSCLITE_HP_MANUKEY_NAME, keyValue, alias);
 				if (rv == 0)
-					driverTracker[listCount].manuID = strtol(keyValue, 0, 16);
+					driverTracker[listCount].manuID = strtol(keyValue, NULL, 16);
 
 				/* get ifdProductID */
-				rv = LTPBundleFindValueWithKey(fullPath, PCSCLITE_HP_PRODKEY_NAME,
-					keyValue, alias);
+				rv = LTPBundleFindValueWithKey(fullPath,
+					PCSCLITE_HP_PRODKEY_NAME, keyValue, alias);
 				if (rv == 0)
 					driverTracker[listCount].productID =
-						strtol(keyValue, 0, 16);
+						strtol(keyValue, NULL, 16);
 
 				/* get ifdFriendlyName */
-				rv = LTPBundleFindValueWithKey(fullPath, PCSCLITE_HP_NAMEKEY_NAME,
-					keyValue, alias);
+				rv = LTPBundleFindValueWithKey(fullPath,
+					PCSCLITE_HP_NAMEKEY_NAME, keyValue, alias);
 				if (rv == 0)
 					driverTracker[listCount].readerName = strdup(keyValue);
 
 				/* get CFBundleExecutable */
-				rv = LTPBundleFindValueWithKey(fullPath, PCSCLITE_HP_LIBRKEY_NAME,
-					keyValue, 0);
+				rv = LTPBundleFindValueWithKey(fullPath,
+					PCSCLITE_HP_LIBRKEY_NAME, keyValue, 0);
 				if (rv == 0)
 				{
 					snprintf(fullLibPath, sizeof(fullLibPath),
 						"%s/%s/Contents/%s/%s",
-						PCSCLITE_HP_DROPDIR, currFP->d_name, PCSC_ARCH, keyValue);
+						PCSCLITE_HP_DROPDIR, currFP->d_name, PCSC_ARCH,
+						keyValue);
 					fullLibPath[sizeof(fullLibPath) - 1] = '\0';
 					driverTracker[listCount].libraryPath = strdup(fullLibPath);
 				}
 
 				/* Get ifdCapabilities */
-				rv = LTPBundleFindValueWithKey(fullPath, PCSCLITE_HP_CPCTKEY_NAME,
-					keyValue, 0);
+				rv = LTPBundleFindValueWithKey(fullPath,
+					PCSCLITE_HP_CPCTKEY_NAME, keyValue, 0);
 				if (rv == 0)
-					driverTracker[listCount].ifdCapabilities = strtol(keyValue, 0, 16);
+					driverTracker[listCount].ifdCapabilities = strtol(keyValue,
+						NULL, 16);
 
 #ifdef DEBUG_HOTPLUG
-					Log2(PCSC_LOG_INFO, "Found driver for: %s",
-						driverTracker[listCount].readerName);
+				Log2(PCSC_LOG_INFO, "Found driver for: %s",
+					driverTracker[listCount].readerName);
 #endif
-
-				listCount++;
 				alias++;
 
+				if (NULL == driverTracker[listCount].readerName)
+					continue;
+
+				listCount++;
 				if (listCount >= driverSize)
 				{
 					int i;
@@ -272,7 +276,8 @@ void HPRescanUsbBus(void)
 						bus->dirname, dev->filename);
 					bus_device[BUS_DEVICE_STRSIZE - 1] = '\0';
 #ifdef DEBUG_HOTPLUG
-					Log2(PCSC_LOG_DEBUG, "Found matching USB device: %s", bus_device);
+					Log2(PCSC_LOG_DEBUG, "Found matching USB device: %s",
+						bus_device);
 #endif
 					newreader = TRUE;
 
@@ -286,7 +291,8 @@ void HPRescanUsbBus(void)
 							readerTracker[j].status = READER_PRESENT;
 							newreader = FALSE;
 #ifdef DEBUG_HOTPLUG
-							Log2(PCSC_LOG_DEBUG, "Refresh USB device: %s", bus_device);
+							Log2(PCSC_LOG_DEBUG, "Refresh USB device: %s",
+								bus_device);
 #endif
 							break;
 						}
@@ -425,7 +431,7 @@ LONG HPSearchHotPluggables(void)
 
 	if (HPReadBundleValues())
 		SYS_ThreadCreate(&usbNotifyThread, THREAD_ATTR_DETACHED,
-			(PCSCLITE_THREAD_FUNCTION( )) HPEstablishUSBNotifications, 0);
+			(PCSCLITE_THREAD_FUNCTION( )) HPEstablishUSBNotifications, NULL);
 
 	return 0;
 }
@@ -500,19 +506,19 @@ LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
 	return 1;
 }	/* End of function */
 
-LONG HPRemoveHotPluggable(int index)
+LONG HPRemoveHotPluggable(int reader_index)
 {
 	SYS_MutexLock(&usbNotifierMutex);
 
-	Log3(PCSC_LOG_INFO, "Removing USB device[%d]: %s", index,
-		readerTracker[index].bus_device);
+	Log3(PCSC_LOG_INFO, "Removing USB device[%d]: %s", reader_index,
+		readerTracker[reader_index].bus_device);
 
-	RFRemoveReader(readerTracker[index].fullName,
-		PCSCLITE_HP_BASE_PORT + index);
-	free(readerTracker[index].fullName);
-	readerTracker[index].status = READER_ABSENT;
-	readerTracker[index].bus_device[0] = '\0';
-	readerTracker[index].fullName = NULL;
+	RFRemoveReader(readerTracker[reader_index].fullName,
+		PCSCLITE_HP_BASE_PORT + reader_index);
+	free(readerTracker[reader_index].fullName);
+	readerTracker[reader_index].status = READER_ABSENT;
+	readerTracker[reader_index].bus_device[0] = '\0';
+	readerTracker[reader_index].fullName = NULL;
 
 	SYS_MutexUnLock(&usbNotifierMutex);
 
