@@ -4,7 +4,7 @@
  * Copyright (C) 2006
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: pcscd.h,v 1.1.1.1 2007-02-13 20:35:27 rousseau Exp $
+ * $Id$
  */
 
 /**
@@ -26,11 +26,7 @@
 
 #define PCSCLITE_CONFIG_DIR		"/etc"
 
-#ifndef USE_IPCDIR
-#define PCSCLITE_IPC_DIR		"/var/run"
-#else
 #define PCSCLITE_IPC_DIR		USE_IPCDIR
-#endif
 
 #define PCSCLITE_READER_CONFIG		PCSCLITE_CONFIG_DIR "/reader.conf"
 #define PCSCLITE_PUBSHM_FILE		PCSCLITE_IPC_DIR "/pcscd.pub"
@@ -40,7 +36,7 @@
 
 #define PCSCLITE_INFINITE_TIMEOUT	4320000		/**< 50 day infinite t/o */
 
-#define PCSCLITE_VERSION_NUMBER		"1.4.0"	/**< Current version */
+#define PCSCLITE_VERSION_NUMBER		"1.4.3"	/**< Current version */
 #define PCSCLITE_CLIENT_ATTEMPTS	120		/**< Attempts to reach sv */
 #define PCSCLITE_MCLIENT_ATTEMPTS	20		/**< Attempts to reach sv */
 #define PCSCLITE_STATUS_POLL_RATE	400000		/**< Status polling rate */
