@@ -1,11 +1,12 @@
 /*
  * MUSCLE SmartCard Development ( http://www.linuxnet.com )
  *
- * Copyright (C) 1999-2005
+ * Copyright (C) 1999-2002
  *  David Corcoran <corcoran@linuxnet.com>
+ * Copyright (C) 1999-2007
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: pcscdaemon.c 2377 2007-02-05 13:13:56Z rousseau $
+ * $Id: pcscdaemon.c 2568 2007-06-19 12:37:13Z rousseau $
  */
 
 /**
@@ -23,6 +24,7 @@
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <fcntl.h>
 #include <errno.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -44,6 +46,7 @@
 #include "readerfactory.h"
 #include "configfile.h"
 #include "powermgt_generic.h"
+#include "utils.h"
 
 #ifndef TRUE
 #define TRUE 1
@@ -68,40 +71,8 @@ void print_usage (char const * const);
 
 PCSCLITE_MUTEX usbNotifierMutex;
 
-#ifdef USE_RUN_PID
-pid_t GetDaemonPid(void);
-pid_t GetDaemonPid(void)
-{
-	FILE *f;
-	pid_t pid;
-
-	/* pids are only 15 bits but 4294967296
-	 * (32 bits in case of a new system use it) is on 10 bytes
-	 */
-	if ((f = fopen(USE_RUN_PID, "rb")) != NULL)
-	{
-#define PID_ASCII_SIZE 11
-		char pid_ascii[PID_ASCII_SIZE];
-
-		fgets(pid_ascii, PID_ASCII_SIZE, f);
-		fclose(f);
-
-		pid = atoi(pid_ascii);
-	}
-	else
-	{
-		Log2(PCSC_LOG_CRITICAL, "Can't open " USE_RUN_PID ": %s",
-			strerror(errno));
-		return -1;
-	}
-
-	return pid;
-} /* GetDaemonPid */
-#endif
-
 int SendHotplugSignal(void)
 {
-#ifdef USE_RUN_PID
 	pid_t pid;
 
 	pid = GetDaemonPid();
@@ -116,7 +87,6 @@ int SendHotplugSignal(void)
 			return EXIT_FAILURE ;
 		}
 	}
-#endif
 
 	return EXIT_SUCCESS;
 } /* SendHotplugSignal */
@@ -205,11 +175,7 @@ void SVCServiceRunLoop(void)
 			rv = CreateContextThread(&dwClientID);
 
  			if (rv != SCARD_S_SUCCESS)
-			{
 				Log1(PCSC_LOG_ERROR, "Problem during the context thread creation");
-				AraKiri = TRUE;
-			}
-
 			break;
 
 		case 2:
@@ -259,18 +225,18 @@ int main(int argc, char **argv)
 #ifdef HAVE_GETOPT_LONG
 	int option_index = 0;
 	static struct option long_options[] = {
-		{"config", 1, 0, 'c'},
-		{"foreground", 0, 0, 'f'},
-		{"help", 0, 0, 'h'},
-		{"version", 0, 0, 'v'},
-		{"apdu", 0, 0, 'a'},
-		{"debug", 0, 0, 'd'},
-		{"info", 0, 0, 0},
-		{"error", 0, 0, 'e'},
-		{"critical", 0, 0, 'C'},
-		{"hotplug", 0, 0, 'H'},
-		{"force-reader-polling", optional_argument, 0, 0},
-		{0, 0, 0, 0}
+		{"config", 1, NULL, 'c'},
+		{"foreground", 0, NULL, 'f'},
+		{"help", 0, NULL, 'h'},
+		{"version", 0, NULL, 'v'},
+		{"apdu", 0, NULL, 'a'},
+		{"debug", 0, NULL, 'd'},
+		{"info", 0, NULL, 0},
+		{"error", 0, NULL, 'e'},
+		{"critical", 0, NULL, 'C'},
+		{"hotplug", 0, NULL, 'H'},
+		{"force-reader-polling", optional_argument, NULL, 0},
+		{NULL, 0, NULL, 0}
 	};
 #endif
 #define OPT_STRING "c:fdhvaeCH"
@@ -380,7 +346,6 @@ int main(int argc, char **argv)
 
 	if (rv == 0)
 	{
-#ifdef USE_RUN_PID
 		pid_t pid;
 
 		/* read the pid file to get the old pid and test if the old pcscd is
@@ -406,16 +371,10 @@ int main(int argc, char **argv)
 				clean_temp_files();
 		}
 		else
-#endif
 		{
 			if (HotPlug)
 			{
-#ifdef USE_RUN_PID
 				Log1(PCSC_LOG_CRITICAL, "file " USE_RUN_PID " do not exist");
-#else
-				Log1(PCSC_LOG_CRITICAL,
-					"pcscd was not configured with --enable-runpid=FILE");
-#endif
 				Log1(PCSC_LOG_CRITICAL, "Hotplug failed");
 				return EXIT_FAILURE;
 			}
@@ -424,10 +383,8 @@ int main(int argc, char **argv)
 				"file " PCSCLITE_PUBSHM_FILE " already exists.");
 			Log1(PCSC_LOG_CRITICAL,
 				"Maybe another pcscd is running?");
-#ifdef USE_RUN_PID
 			Log1(PCSC_LOG_CRITICAL,
 				"I can't read process pid from " USE_RUN_PID);
-#endif
 			Log1(PCSC_LOG_CRITICAL,
 				"Remove " PCSCLITE_PUBSHM_FILE " and " PCSCLITE_CSOCK_NAME);
 			Log1(PCSC_LOG_CRITICAL,
@@ -460,21 +417,29 @@ int main(int argc, char **argv)
 	signal(SIGINT, signal_trap);
 	signal(SIGHUP, signal_trap);
 
-#ifdef USE_RUN_PID
 	/*
 	 * Record our pid to make it easier
 	 * to kill the correct pcscd
 	 */
 	{
-		FILE *f;
+		int f;
 
-		if ((f = fopen(USE_RUN_PID, "wb")) != NULL)
+		if ((f = SYS_OpenFile(USE_RUN_PID, O_RDWR | O_CREAT, 00644)) != -1)
 		{
-			fprintf(f, "%u\n", (unsigned) getpid());
-			fclose(f);
+			char pid[PID_ASCII_SIZE];
+
+			snprintf(pid, sizeof(pid), "%u", (unsigned) getpid());
+			SYS_WriteFile(f, pid, strlen(pid));
+			SYS_CloseFile(f);
+
+			/* set mode so that the file is world readable.
+			 * The file is used by libpcsclite */
+			SYS_Chmod(USE_RUN_PID, 0644);
 		}
+		else
+			Log2(PCSC_LOG_CRITICAL, "cannot create " USE_RUN_PID ": %s",
+				strerror(errno));
 	}
-#endif
 
 	/*
 	 * If PCSCLITE_IPC_DIR does not exist then create it
@@ -585,12 +550,10 @@ void clean_temp_files(void)
 		Log2(PCSC_LOG_ERROR, "Cannot unlink " PCSCLITE_CSOCK_NAME ": %s",
 			strerror(errno));
 
-#ifdef USE_RUN_PID
 	rv = SYS_Unlink(USE_RUN_PID);
 	if (rv != 0)
 		Log2(PCSC_LOG_ERROR, "Cannot unlink " USE_RUN_PID ": %s",
 			strerror(errno));
-#endif
 }
 
 void signal_reload(int sig)
@@ -638,7 +601,7 @@ void print_version (void)
 {
 	printf("%s version %s.\n",  PACKAGE, VERSION);
 	printf("Copyright (C) 1999-2002 by David Corcoran <corcoran@linuxnet.com>.\n");
-	printf("Copyright (C) 2001-2005 by Ludovic Rousseau <ludovic.rousseau@free.fr>.\n");
+	printf("Copyright (C) 2001-2007 by Ludovic Rousseau <ludovic.rousseau@free.fr>.\n");
 	printf("Copyright (C) 2003-2004 by Damien Sauveron <sauveron@labri.fr>.\n");
 	printf("Report bugs to <sclinux@linuxnet.com>.\n");
 }
