@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.c 2385 2007-02-05 13:55:01Z rousseau $
+ * $Id: winscard.c 2567 2007-06-18 14:44:57Z rousseau $
  */
 
 /**
@@ -32,16 +32,16 @@
  * corcoran@musclecard.com.
  *
  *
- * @section API Routines
+ * @section API_Routines
  *
- * These routines specified here are winscard routines like those in the
+ * These routines specified here are winscard.h routines like those in the
  * winscard API provided under Windows(R). These are compatible with the
  * Microsoft(R) API calls. This list of calls is mainly an abstraction of
  * readers. It gives a common API for communication to most readers in a
  * homogeneous fashion.
  *
- * Since all functions can produce a wide array of errors, please refer to §
- * Error codes for a list of error returns.
+ * Since all functions can produce a wide array of errors, please refer to
+ * pcsclite.h for a list of error returns.
  *
  * For a human readable representation of an error the function
  * pcsc_stringify_error() is declared in pcsclite.h. This function is not
@@ -189,9 +189,9 @@ static void profile_end(const char *f, int line)
 /** Some defines for context stack. */
 #define SCARD_NO_LOCK            0
 
-SCARD_IO_REQUEST g_rgSCardT0Pci = { SCARD_PROTOCOL_T0, 8 };
-SCARD_IO_REQUEST g_rgSCardT1Pci = { SCARD_PROTOCOL_T1, 8 };
-SCARD_IO_REQUEST g_rgSCardRawPci = { SCARD_PROTOCOL_RAW, 8 };
+SCARD_IO_REQUEST g_rgSCardT0Pci = { SCARD_PROTOCOL_T0, sizeof(SCARD_IO_REQUEST) };
+SCARD_IO_REQUEST g_rgSCardT1Pci = { SCARD_PROTOCOL_T1, sizeof(SCARD_IO_REQUEST) };
+SCARD_IO_REQUEST g_rgSCardRawPci = { SCARD_PROTOCOL_RAW, sizeof(SCARD_IO_REQUEST) };
 
 /**
  * @brief Creates an Application Context for a client.
@@ -341,6 +341,10 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 		SYS_USleep(PCSCLITE_STATUS_POLL_RATE + 10);
 	}
 
+	/* the reader has been removed while we were waiting */
+	if (NULL == rContext->readerState)
+		return SCARD_E_NO_SMARTCARD;
+
 	/*******************************************
 	 *
 	 * This section tries to determine the
@@ -821,7 +825,8 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 	/*
 	 * wait until a possible transaction is finished
 	 */
-	if ((rContext->dwLockId != 0) && (rContext->dwLockId != hCard))
+	if ((dwDisposition != SCARD_LEAVE_CARD) && (rContext->dwLockId != 0)
+		&& (rContext->dwLockId != hCard))
 	{
 		Log1(PCSC_LOG_INFO, "Waiting for release of lock");
 		while (rContext->dwLockId != 0)
@@ -829,6 +834,10 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 		Log1(PCSC_LOG_INFO, "Lock released");
 	}
 
+	/* the reader has been removed while we were waiting */
+	if (NULL == rContext->readerState)
+		return SCARD_E_NO_SMARTCARD;
+
 	/*
 	 * Unlock any blocks on this context
 	 */
@@ -1207,6 +1216,9 @@ LONG SCardStatus(SCARDHANDLE hCard, LPSTR mszReaderNames,
 	LONG rv;
 	PREADER_CONTEXT rContext = NULL;
 
+	if (hCard == 0)
+		return SCARD_E_INVALID_HANDLE;
+
 	rv = RFReaderInfoById(hCard, &rContext);
 
 	/*
